@@ -1,10 +1,12 @@
 package Mojolicious::Plugin::AssetPack;
 use Mojo::Base 'Mojolicious::Plugin';
+
+use Mojo::Util 'trim';
 use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 has minify => sub { shift->_app->mode eq 'development' ? 0 : 1 };
 
@@ -152,7 +154,7 @@ sub _process_from_def {
       bless $asset, 'Mojolicious::Plugin::AssetPack::Asset::Null' if $class eq '<';
       push @{$process{$topic}}, $asset;
     }
-    elsif (/^\!\s*(.+)/) { $topic = $1; }
+    elsif (/^\!\s*(.+)/) { $topic = trim $1; }
   }
 
   $self->process($_ => @{$process{$_}}) for keys %process;
@@ -220,7 +222,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.13
+1.14
 
 =head1 SYNOPSIS
 
